<?php

/**
 * The admin-specific functionality of the plugin.
 *
 * @link       https://www.diyva.life
 * @since      1.0.0
 *
 * @package    Diyva_Voice_Survey
 * @subpackage Diyva_Voice_Survey/admin
 */

/**
 * The admin-specific functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    Diyva_Voice_Survey
 * @subpackage Diyva_Voice_Survey/admin
 * @author     Diyva <sales@datajhoom.com>
 */
class Diyva_Voice_Survey_Admin {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of this plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;

	}

	/**
	 * Register the stylesheets for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Diyva_Voice_Survey_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Diyva_Voice_Survey_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_style( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'css/diyva-voice-survey-admin.css', array(), $this->version, 'all' );

	}

	/**
	 * Register the JavaScript for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Diyva_Voice_Survey_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Diyva_Voice_Survey_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_script( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'js/diyva-voice-survey-admin.js', array( 'jquery' ), $this->version, false );

	}
	
	/**
	 * Plugin Menu 
	 */
	public function plugin_menu() { 
		add_menu_page('DIYVA Voice Survey', 'DIYVA Voice Survey', 'manage_options', 'diyva-voice-survey-plugin', array($this, 'diyva_voice_survey_main'), plugins_url('../assets/images/diyva-icon.jpg', __FILE__) );
		add_submenu_page('diyva-voice-survey-plugin', 'Dialog Settings', 'Dialog Settings', 'manage_options', 'diyva-voice-survey-plugin-dialog-settings', array($this, 'diyva_voice_survey_dialog_settings') );
		add_submenu_page('diyva-voice-survey-plugin', 'Display Settings', 'Display Settings', 'manage_options', 'diyva-voice-survey-plugin-display-settings', array($this, 'diyva_voice_survey_display_settings') );
		add_submenu_page('diyva-voice-survey-plugin', 'Query Parameters Settings', 'Query Parameters', 'manage_options', 'diyva-voice-survey-plugin-query-parameters', array($this, 'diyva_voice_survey_query_parameters') );
	}
	
	/**
	 * Plugin main page 
	 */
	public function diyva_voice_survey_main() {
		include_once( 'partials/diyva-voice-survey-admin-display.php' );
	}

	/**
	 * Plugin dialog settings page 
	 */
	public function diyva_voice_survey_dialog_settings() {
		include_once( 'partials/diyva-voice-survey-admin-dialog-settings.php' );
	}
	
	/**
	 * Plugin display settings page 
	 */
	public function diyva_voice_survey_display_settings() {
		include_once( 'partials/diyva-voice-survey-admin-display-settings.php' );
	}
	
	/**
	 * Plugin query parameters settings page 
	 */
	public function diyva_voice_survey_query_parameters() {
		include_once( 'partials/diyva-voice-survey-admin-query-parameters.php' );
	}
	
	/**
	 * Register Plugin setting
	 */
	public function register_settings() {
		register_setting( $this->plugin_name.'-dialog-settings', $this->plugin_name.'-dialog-settings' );
		register_setting( $this->plugin_name.'-display-settings', $this->plugin_name.'-display-settings' );
		register_setting( $this->plugin_name.'-query-parameters-settings', $this->plugin_name.'-query-parameters-settings' );
	}
	
}