<?php

/**
 * Provide a admin area view for the plugin
 *
 * This file is used to markup the admin-facing aspects of the plugin.
 *
 * @link       https://www.diyva.life
 * @since      1.0.0
 *
 * @package    Diyva_Voice_Survey
 * @subpackage Diyva_Voice_Survey/admin/partials
 */
?>

<!-- This file should primarily consist of HTML with a little bit of PHP. -->


<div class="wrap">

	<h2><?php echo esc_html( get_admin_page_title() ); ?></h2>
	
	<form method="post" name="display-settings" action="options.php">
		
		<?php
			
			$show_hide_settings = array(
				'home' => 'Home Page',
				'posts' => 'Posts',
				'pages' => 'Pages',
				'archive' => 'Archive pages',
				'category' => 'Category pages',
				'page_404' => '404 Page',
			);

			// woocommerce 
			if ( class_exists( 'WooCommerce' ) ) {
				$show_hide_settings['WooCommerce'] = '';
				$show_hide_settings['woo_product'] = 'Single Product pages';
				$show_hide_settings['woo_shop'] = 'Shop (Product Archive page)';
				$show_hide_settings['woo_cart'] = 'Cart page';
				$show_hide_settings['woo_checkout'] = 'Checkout page';
				$show_hide_settings['woo_checkout_thank_you'] = 'Thank you page';
				$show_hide_settings['woo_account'] = 'Account page';
			}
			
			// custom post types
			$custom_post_types = get_post_types( array('public' => true, '_builtin' => false) );
			
			// woocommerce product working in different way..
				// unset may not be the perfect in all times.
			unset($custom_post_types['product']);

			// not empty array - custom post types
			if (!empty($custom_post_types)) {
				// title custom post type
				$show_hide_settings['Custom Post Types'] = '';
				// merge 
				$show_hide_settings = array_merge($show_hide_settings, $custom_post_types);
			}

			//Grab all options
			$settings_path 	= $this->plugin_name.'-display-settings';
			$options 		= get_option($settings_path);
			
			$display_settings = (isset($options['display'])) ? $options['display'] : '';

			$global_display = (isset($display_settings['global_display'])) ? esc_html($display_settings['global_display']) : 'show';

		?>
		
		<?php
			settings_fields( $settings_path );
			do_settings_sections( $settings_path );
		?>
		
		<table class="form-table">
			<tbody>
				<tr>
					<th>Global</th>
					<td class="display-flex">
						<p class="space-right">
							<label>
								<input name="<?php echo esc_attr($settings_path); ?>[display][global_display]" value="show" type="radio" <?php checked( 'show' == $global_display ); ?> />
								<span>Show on all pages</span>
							</label>
						</p>
						<p>
							<label>
								<input name="<?php echo esc_attr($settings_path); ?>[display][global_display]" value="hide" type="radio" <?php checked( 'hide' == $global_display ); ?> />
								<span>Hide on all pages</span>
							</label>
						</p>
					</td>
				</tr>
			</tbody>
		</table>
		
		<p class="description" style="margin:16px 0px 20px 0px;">
			<strong>Override the Global settings</strong>
		</p>
		
		<table class="form-table">
			<tbody>
			
					<?php
					
						foreach ($show_hide_settings as $key => $value) {
							
							if ( '' == $value ) {
								// heading
								?>
								<tr>
									<th><strong><?php echo esc_html($key); ?>: </strong></th>
									<td >
									</td>
								</tr>
								<?php
							} else {
								$is_checked_show_hide = (isset($options['display'][$key])) ? esc_html($options['display'][$key]) : 'g';
								?>
								<tr>
									<th><?php echo esc_html($value); ?>:</th>
									<td class="display-flex">
										<p class="space-right">
											<label>
												<input name="<?php echo esc_attr($settings_path); ?>[display][<?php echo esc_attr($key); ?>]" value="show" type="radio" <?php checked( 'show' == $is_checked_show_hide ); ?> />
												<span>Show</span>
											</label>
										</p>
										<p class="space-right">
											<label>
												<input name="<?php echo esc_attr($settings_path); ?>[display][<?php echo esc_attr($key); ?>]" value="hide" type="radio" <?php checked( 'hide' == $is_checked_show_hide ); ?> />
												<span>Hide</span>
											</label>
										</p>
										<p>
											<label>
												<input name="<?php echo esc_attr($settings_path); ?>[display][<?php echo esc_attr($key); ?>]" value="g" type="radio" <?php checked( '' == $is_checked_show_hide || 'g' == $is_checked_show_hide ); ?> />
												<span>Global</span>
											</label>
										</p>
									</td>
								</tr>
								<?php
							}
						
						}

					?>
			</tbody>
		</table>
		
		

		<?php submit_button('Save all changes', 'primary','submit', TRUE); ?>
		
	</form>
	
</div>
