<?php

/**
 * Provide a admin area view for the plugin
 *
 * This file is used to markup the admin-facing aspects of the plugin.
 *
 * @link       https://www.diyva.life
 * @since      1.0.0
 *
 * @package    Diyva_Voice_Survey
 * @subpackage Diyva_Voice_Survey/admin/partials
 */
?>

<!-- This file should primarily consist of HTML with a little bit of PHP. -->


<div class="wrap">

	<h2><?php echo esc_html( get_admin_page_title() ); ?></h2>

	<form method="post" name="query-parameter-settings" action="options.php">

		<?php

		//Grab all options
		$settings_path 	= $this->plugin_name.'-query-parameters-settings';
		$options 				= get_option($settings_path);
		
		$qp_user_id			= (isset($options['query_parameter']['user_id'])) ? esc_html($options['query_parameter']['user_id']) : 'disabled';
		$qp_post_id			= (isset($options['query_parameter']['post_id'])) ? esc_html($options['query_parameter']['post_id']) : 'disabled';
		$qp_category_id	= (isset($options['query_parameter']['category_id'])) ? esc_html($options['query_parameter']['category_id']) : 'disabled';
		
		if ( class_exists( 'WooCommerce' ) ) {
			$qp_pc_id				= (isset($options['query_parameter']['product_category_id'])) ? esc_html($options['query_parameter']['product_category_id']) : 'disabled';
			$qp_order_id		= (isset($options['query_parameter']['order_id'])) ? esc_html($options['query_parameter']['order_id']) : 'disabled';
			$qp_couponcode	= (isset($options['query_parameter']['couponcode'])) ? esc_html($options['query_parameter']['couponcode']) : 'disabled';
		}

		function getToolTip() {
				?>
				<span class="diyva-tooltip-text">Select the following properties to be saved with the dialog response and viewable in the DIYVA Analytics Dashboard. Visit <a href="https://diyva.life/wordpress-plugin" target="_blank">our website</a> to learn how to embed the plugin in your WordPress site.</span>
				<?php
		}
		 ?>

		<?php
			settings_fields( $settings_path );
			do_settings_sections( $settings_path );
		?>

		<table class="form-table">
			<tbody>
				<tr>
					<th><div class="diyva-tooltip-box">user_id<?php if('enabled' == $qp_user_id) getToolTip(); ?></div></th>
					<td >
						<p>
							<label>
								<input name="<?php echo esc_attr($settings_path); ?>[query_parameter][user_id]" value="enabled" type="checkbox" <?php checked( 'enabled' == $qp_user_id ); ?> />
								<span>Enable</span>
							</label>
						</p>
					</td>
				</tr>
				<tr>
					<th><div class="diyva-tooltip-box">post_id<?php if('enabled' == $qp_post_id) getToolTip(); ?></div></th>
					<td >
						<p>
							<label>
								<input name="<?php echo esc_attr($settings_path); ?>[query_parameter][post_id]" value="enabled" type="checkbox" <?php checked( 'enabled' == $qp_post_id ); ?> />
								<span>Enable</span>
							</label>
						</p>
					</td>
				</tr>
				<tr>
					<th><div class="diyva-tooltip-box">category_id<?php if('enabled' == $qp_category_id) getToolTip(); ?></div></th>
					<td >
						<p>
							<label>
								<input name="<?php echo esc_attr($settings_path); ?>[query_parameter][category_id]" value="enabled" type="checkbox" <?php checked( 'enabled' == $qp_category_id ); ?> />
								<span>Enable</span>
							</label>
						</p>
					</td>
				</tr>
				<?php if ( class_exists( 'WooCommerce' ) ) { ?>
				<tr>
					<th><div class="diyva-tooltip-box">product_category_id<?php if('enabled' == $qp_pc_id) getToolTip(); ?></div></th>
					<td >
						<p>
							<label>
								<input name="<?php echo esc_attr($settings_path); ?>[query_parameter][product_category_id]" value="enabled" type="checkbox" <?php checked( 'enabled' == $qp_pc_id ); ?> />
								<span>Enable</span>
							</label>
						</p>
					</td>
				</tr>
				<tr>
					<th><div class="diyva-tooltip-box">order_id<?php if('enabled' == $qp_order_id) getToolTip(); ?></div></th>
					<td >
						<p>
							<label>
								<input name="<?php echo esc_attr($settings_path); ?>[query_parameter][order_id]" value="enabled" type="checkbox" <?php checked( 'enabled' == $qp_order_id ); ?> />
								<span>Enable</span>
							</label>
						</p>
					</td>
				</tr>
				<tr>
					<th><div class="diyva-tooltip-box">couponcode<?php if('enabled' == $qp_couponcode) getToolTip(); ?></div></th>
					<td >
						<p>
							<label>
								<input name="<?php echo esc_attr($settings_path); ?>[query_parameter][couponcode]" value="enabled" type="checkbox" <?php checked( 'enabled' == $qp_couponcode ); ?> />
								<span>Enable</span>
							</label>
						</p>
					</td>
				</tr>
				<?php } ?>
			</tbody>
		</table>

		<?php submit_button('Save all changes', 'primary','submit', TRUE); ?>

	</form>

</div>
