<?php

/**
 * The plugin bootstrap file
 *
 * This file is read by WordPress to generate the plugin information in the plugin
 * admin area. This file also includes all of the dependencies used by the plugin,
 * registers the activation and deactivation functions, and defines a function
 * that starts the plugin.
 *
 * @link              https://www.diyva.life
 * @since             1.0.0
 * @package           Diyva_Voice_Survey
 *
 * @wordpress-plugin
 * Plugin Name:       DIYVA Voice Survey
 * Plugin URI:        https://wordpress.org/plugins/diyva-voice-survey/
 * Description:       Use this plugin to enable frictionless conversational voice surveys to gather product feedback and measure customer satisfaction.
 * Version:           1.0.0
 * Author:            Diyva
 * Author URI:        https://www.diyva.life
 * License:           GPL-2.0+
 * License URI:       http://www.gnu.org/licenses/gpl-2.0.txt
 * Text Domain:       diyva-voice-survey
 * Domain Path:       /languages
 */

// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

/**
 * Currently plugin version.
 * Start at version 1.0.0 and use SemVer - https://semver.org
 * Rename this for your plugin and update it as you release new versions.
 */
define( 'DIYVA_VOICE_SURVEY_VERSION', '1.0.0' );

/**
 * The code that runs during plugin activation.
 * This action is documented in includes/class-diyva-voice-survey-activator.php
 */
function activate_diyva_voice_survey() {
	require_once plugin_dir_path( __FILE__ ) . 'includes/class-diyva-voice-survey-activator.php';
	Diyva_Voice_Survey_Activator::activate();
}

/**
 * The code that runs during plugin deactivation.
 * This action is documented in includes/class-diyva-voice-survey-deactivator.php
 */
function deactivate_diyva_voice_survey() {
	require_once plugin_dir_path( __FILE__ ) . 'includes/class-diyva-voice-survey-deactivator.php';
	Diyva_Voice_Survey_Deactivator::deactivate();
}

register_activation_hook( __FILE__, 'activate_diyva_voice_survey' );
register_deactivation_hook( __FILE__, 'deactivate_diyva_voice_survey' );

/**
 * The core plugin class that is used to define internationalization,
 * admin-specific hooks, and public-facing site hooks.
 */
require plugin_dir_path( __FILE__ ) . 'includes/class-diyva-voice-survey.php';

/**
 * Begins execution of the plugin.
 *
 * Since everything within the plugin is registered via hooks,
 * then kicking off the plugin from this point in the file does
 * not affect the page life cycle.
 *
 * @since    1.0.0
 */
function run_diyva_voice_survey() {

	$plugin = new Diyva_Voice_Survey();
	$plugin->run();

}
run_diyva_voice_survey();


