<?php

/**
 * The public-facing functionality of the plugin.
 *
 * @link       https://www.diyva.life
 * @since      1.0.0
 *
 * @package    Diyva_Voice_Survey
 * @subpackage Diyva_Voice_Survey/public
 */

/**
 * The public-facing functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the public-facing stylesheet and JavaScript.
 *
 * @package    Diyva_Voice_Survey
 * @subpackage Diyva_Voice_Survey/public
 * @author     Diyva <sales@datajhoom.com>
 */
 
class Diyva_Voice_Survey_Public {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of the plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;
		
		// register shortcode
		add_shortcode('diyva_voice_dialog', array($this, 'diyva_voice_dialog_shortcode'));
	}

	/**
	 * Register the stylesheets for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Diyva_Voice_Survey_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Diyva_Voice_Survey_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_style( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'css/diyva-voice-survey-public.css', array(), $this->version, 'all' );
			
		// add font awesome
		if (!wp_style_is( 'fontawesome', 'enqueued' )) {
			wp_register_style( 'fontawesome', '//maxcdn.bootstrapcdn.com/font-awesome/4.7.0/css/font-awesome.min.css', false, '4.7.0' );
			wp_enqueue_style( 'fontawesome' );
		} 

	}

	/**
	 * Register the JavaScript for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Diyva_Voice_Survey_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Diyva_Voice_Survey_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_script( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'js/diyva-voice-survey-public.js', array( 'jquery' ), $this->version, false );

	}
	
	public function show_or_hide() { 
		
		// page id
		$this_page_id = get_the_ID();

		// yes to display style and no to hide styles
		$display 			= 'yes';
		
		// display settings
		$display_fallback 	= array('global_display'=>'show');
		$settings_path 		= $this->plugin_name.'-display-settings';
		$options 			= get_option($settings_path);	
		$display_settings   = (isset($options['display'])) ? $options['display'] : $display_fallback;
		
		// global display settings
		$show_or_hide 		= (isset($display_settings['global_display'])) ? esc_html($display_settings['global_display']) : 'show';	
		
		// post type
		$post_type = get_post_type();
		
		if ( 'hide' == $show_or_hide ) {
			
			// global value: hide on all pages
			$display = 'no';
			
			// is_home and is_front_page - combined. 
			if ( is_home() || is_front_page() ) {
				if ( isset( $display_settings['home'] ) && 'show' == $display_settings['home'] ) {
					$display = 'yes';
					return $display;
				}
			}
			
			 if ( is_singular() ) {
				// singular post .. any post type, single page

				// is_single (post type: posts or other(custom post type or so ..), but not pages )
				if ( is_single() ) {
					
					if ( 'post' == $post_type ) {
						// post type: post (singular page)
						if ( isset( $display_settings['posts'] ) && 'show' == $display_settings['posts'] ) {
							$display = 'yes';
							return $display;
						}
					} else {
						// custom post type
						$custom_post_types = get_post_types( array('public' => true, '_builtin' => false) );
						unset($custom_post_types['product']);

						if ( !empty($custom_post_types ) ) {
							if ( in_array( $post_type, $custom_post_types ) ) {
								if ( isset( $display_settings[$post_type] ) && 'show' == $display_settings[$post_type] ) {
									$display = 'yes';
									return $display;
								}
							}
						}
						
					}
				}

				// post type: page (but not home/front page)
				if ( is_page() ) {
					if ( ( !is_home() ) && ( !is_front_page() ) ) {
						if ( isset( $display_settings['pages'] ) && 'show' == $display_settings['pages'] ) {
							$display = 'yes';
							return $display;
						}
					}
				}

				// woocommerce (shop page is at archive)
				if ( class_exists( 'WooCommerce' ) ) {
					
					if ( function_exists( 'is_product' ) && is_product() ) {
						if ( isset( $display_settings['woo_product'] ) && 'show' == $display_settings['woo_product']  ) {
							$display = 'yes';
							return $display;
						}
					}

					if ( function_exists( 'is_cart' ) && is_cart() ) {
						if ( isset( $display_settings['woo_cart'] ) && 'show' == $display_settings['woo_cart']  ) {
							$display = 'yes';
							return $display;
						}
					}

					if ( function_exists( 'is_checkout' ) && is_checkout() && !empty( is_wc_endpoint_url('order-received') ) ) {
						if ( isset( $display_settings['woo_checkout_thank_you'] ) && 'show' == $display_settings['woo_checkout_thank_you']  ) {
							$display = 'yes';
							return $display;
						}
					}
					
					if ( function_exists( 'is_checkout' ) && is_checkout() && empty( is_wc_endpoint_url('order-received') ) ) {
						if ( isset( $display_settings['woo_checkout'] ) && 'show' == $display_settings['woo_checkout']  ) {
							$display = 'yes';
							return $display;
						}
					}
					
					if ( function_exists( 'is_account_page' ) && is_account_page() ) {
						if ( isset( $display_settings['woo_account'] ) && 'show' == $display_settings['woo_account']  ) {
							$display = 'yes';
							return $display;
						}
					}

				}
				
			} elseif ( is_archive() ) {
				// loop posts

				// woocommerce shop - archive
				if ( class_exists( 'WooCommerce' ) ) {
					if ( function_exists( 'is_shop' ) && is_shop() ) {
						if ( isset( $display_settings['woo_shop'] ) && 'show' == $display_settings['woo_shop']  ) {
							$display = 'yes';
							return $display;
						}
					}
				}

				// category
				if ( is_category() ) {
					if ( isset( $display_settings['category'] ) && 'show' == $display_settings['category'] ) {
						$display = 'yes';
						return $display;
					}
				}
				
				// archive
				if ( is_archive() ) {
					if ( isset( $display_settings['archive'] ) && 'show' == $display_settings['archive'] ) {
						$display = 'yes';
						return $display;
					}
				}
			}


			// 404 page
			if ( is_404() ) {
				if ( isset( $display_settings['page_404'] ) && 'show' == $display_settings['page_404'] ) {
					$display = 'yes';
					return $display;
				}
			}
	
		} else {
			// global value: show on all pages
			$display = 'yes';
			
			// if any page override to hide

			// is_home and is_front_page - combined. 
			if ( is_home() || is_front_page() ) {
				if ( isset( $display_settings['home'] ) && 'hide' == $display_settings['home'] ) {
					$display = 'no';
					return $display;
				}
			}
			
			if ( is_singular() ) {
				// singular post .. any post type, single page

				// is_single (post type: posts or other(custom post type or so ..), but not pages )
				if ( is_single() ) {
					
					if ( 'post' == $post_type ) {
						
						if ( isset( $display_settings['posts'] ) && 'hide' == $display_settings['posts'] ) {
							$display = 'no';
							return $display;
						}
					} else {
						// custom post type (but not woo single product pages)

						$custom_post_types = get_post_types( array('public' => true, '_builtin' => false) );
						unset($custom_post_types['product']);

						if ( !empty($custom_post_types ) ) {
							if ( in_array( $post_type, $custom_post_types ) ) {
								if ( isset( $display_settings[$post_type] ) && 'hide' == $display_settings[$post_type] ) {
									$display = 'yes';
									return $display;
								}
							}
						}
						
					}
				}
				
				// page
				if ( is_page() ) {
					if ( ( !is_home() ) && ( !is_front_page() ) ) {
						if ( isset( $display_settings['pages'] ) && 'hide' == $display_settings['pages'] ) {
							$display = 'no';
							return $display;
						}
					}
				}

				// woocommerce (shop page is at archive)
				if ( class_exists( 'WooCommerce' ) ) {
					
					if ( function_exists( 'is_product' ) && is_product() ) {
						if ( isset( $display_settings['woo_product'] ) && 'hide' == $display_settings['woo_product'] ) {
							$display = 'no';
							return $display;
						}
					}

					if ( function_exists( 'is_cart' ) && is_cart() ) {
						if ( isset( $display_settings['woo_cart'] ) && 'hide' == $display_settings['woo_cart']  ) {
							$display = 'no';
							return $display;
						}
					}
					
					if ( function_exists( 'is_checkout' ) && is_checkout() && !empty( is_wc_endpoint_url('order-received') ) ) {
						if ( isset( $display_settings['woo_checkout_thank_you'] ) && 'hide' == $display_settings['woo_checkout_thank_you']  ) {
							$display = 'no';
							return $display;
						}
					}
					
					if ( function_exists( 'is_checkout' ) && is_checkout() && empty( is_wc_endpoint_url('order-received') ) ) {
						if ( isset( $display_settings['woo_checkout'] ) && 'hide' == $display_settings['woo_checkout']  ) {
							$display = 'no';
							return $display;
						}
					}

					if ( function_exists( 'is_account_page' ) && is_account_page() ) {
						if ( isset( $display_settings['woo_account'] ) && 'hide' == $display_settings['woo_account']  ) {
							$display = 'no';
							return $display;
						}
					}

				}
				
			} elseif ( is_archive() ) {
				// loop posts

				// woocommerce shop - archive
				if ( class_exists( 'WooCommerce' ) ) {
					if ( function_exists( 'is_shop' ) && is_shop() ) {
						if ( isset( $display_settings['woo_shop'] ) && 'hide' == $display_settings['woo_shop']  ) {
							$display = 'no';
							return $display;
						}
					}
				}

				// category
				if ( is_category() ) {
					if ( isset( $display_settings['category'] ) && 'hide' == $display_settings['category'] ) {
						$display = 'no';
						return $display;
					}
				}
				
				// archive
				if ( is_archive() ) {
					if ( isset( $display_settings['archive'] ) && 'hide' == $display_settings['archive'] ) {
						$display = 'no';
						return $display;
					}
				}

			}
			
			// 404 page
			if ( is_404() ) {
				if ( isset( $display_settings['page_404'] ) && 'hide' == $display_settings['page_404'] ) {
					$display = 'no';
					return $display;
				}
			}
		}
		return $display;
	}
	
	/**
	 * function that runs when shortcode is called
	 */
	public function diyva_voice_dialog_shortcode() { 
		
		// fetch dialog settings
		$dialog_settings_path 	= $this->plugin_name.'-dialog-settings';
		$dialog_options 				= get_option($dialog_settings_path);
		
		// fetch query parameters settings
		$qp_settings_path 			= $this->plugin_name.'-query-parameters-settings';
		$qp_options 						= get_option($qp_settings_path);

		$dailog_url 						= $dialog_options['dailog_url'];
		
		$show_or_hide 					= $this->show_or_hide();
		
		ob_start();
		
		if('yes' == $show_or_hide) {

			if($dailog_url) {
				
				$qp_user_id 				= (isset($qp_options['query_parameter']['user_id'])) ? esc_html($qp_options['query_parameter']['user_id']) : 'disabled';
				$qp_post_id 				= (isset($qp_options['query_parameter']['post_id'])) ? esc_html($qp_options['query_parameter']['post_id']) : 'disabled';
				$qp_category_id 		= (isset($qp_options['query_parameter']['category_id'])) ? esc_html($qp_options['query_parameter']['category_id']) : 'disabled';
				if ( class_exists( 'WooCommerce' ) ) {
					$qp_pc_id				 		= (isset($qp_options['query_parameter']['product_category_id'])) ? esc_html($qp_options['query_parameter']['product_category_id']) : 'disabled';
					$qp_order_id 				= (isset($qp_options['query_parameter']['order_id'])) ? esc_html($qp_options['query_parameter']['order_id']) : 'disabled';
					$qp_couponcode 			= (isset($qp_options['query_parameter']['couponcode'])) ? esc_html($qp_options['query_parameter']['couponcode']) : 'disabled';
				}
				
				global $post;
				global $wp;
				
				if(class_exists( 'WooCommerce' ) && is_checkout() && !empty( is_wc_endpoint_url('order-received')) ) {
					$or_id					= absint($wp->query_vars['order-received']);
					$order          = new WC_Order($or_id);
    			$coupon_codes   = $order->get_coupon_codes();
					$coupon_code   	= count($coupon_codes) > 0 ? $coupon_codes[0] : '';
				}

				$user_id						= $qp_user_id === 'enabled' && is_user_logged_in() ? 'user_id='.get_current_user_id().'&' : '';
				$post_id						= $qp_post_id === 'enabled' ? 'post_id='.$post->ID.'&' : '';
				$category_id				= $qp_category_id === 'enabled' && is_category() ? 'category_id='.get_category( get_query_var( 'cat' ) )->cat_ID.'&' : '';
				
				$woo_qp							= '';
				if ( class_exists( 'WooCommerce' ) ) {
					$pc_id							= $qp_pc_id === 'enabled' && is_product_category() ? 'product_category_id='.get_queried_object()->term_id.'&' : '';
					$order_id						= $qp_order_id === 'enabled' && is_checkout() && !empty( is_wc_endpoint_url('order-received')) ? 'order_id='.$or_id.'&' : '';
					$couponcode					= $qp_couponcode === 'enabled' && is_checkout() && !empty( is_wc_endpoint_url('order-received')) ? 'couponcode='.$coupon_code.'&' : '';
					$woo_qp							= $pc_id.''.$order_id.''.$couponcode;
				}

				$query_parameters		= '?'.$user_id.''.$post_id.''.$category_id.''.$woo_qp;
			?>
			
			<button class="diyva-dialog-user-feedback-click">
				<i class="fas fa-poll-h"></i> Send us your feedback
				<div class="diyva-dialog-survey-group">
					<iframe class="diyva-dialog-user-feedback-iframe" height=450 width=350 allow="microphone" src="<?php echo esc_url($dailog_url).esc_url($query_parameters) ?>"></iframe>
					<div class="diyva-dialog-remove-button"><i class="fa fa-times" aria-hidden="true"></i></div>
				</div>
			</button>
		
			<?php
			
			} else {
			
			?>
		
			<button class="diyva-dialog-user-feedback-click">
				<i class="fas fa-poll-h"></i> Send us your feedback
				<div class="diyva-dialog-survey-group diyva-dialog-survey-group-no-dialog" >
					<div class="diyva-dialog-no-dialog">
						No Dailog URL Found! <br/>
						Add <a href="<?php echo esc_url(admin_url( 'admin.php?page=diyva-voice-survey-plugin-dialog-settings' )); ?>" target="_blank">Dailog URL</a> at pluign Settings <br/>
						If already added, <strong>clear the Cache</strong> and try. <br/>
						If still an issue, please contact plugin developers.
					</div>
					<div class="diyva-dialog-remove-button"><i class="fa fa-times" aria-hidden="true"></i></div>
				</div>
			</button>
			
			<?php
		
			}
		}
		return ob_get_clean();
	} 
}
